This is the mail archive of the binutils@sourceware.org mailing list for the binutils project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

Re: [3/3] Spelling fixes


Hi Stephen,

Thanks for reporting these problems.

I have checked in the attached patch in order to fix the spelling mistakes in the binutils sources. The only omissions are the .po files, which will wait for updated translations to be submitted, and the libiberty/pex-win32.c source file. The files in the libiberty directory are not part of the binutils project - they are their own project.

Cheers
  Nick

bfd/ChangeLog
2011-06-02  Nick Clifton  <nickc@redhat.com>

	* coff-mcore.c: Fix spelling typo.
	* coff-stgo32.c: Likewise.
	* elf32-arm.c: Likewise.
	* elf32-avr.c: Likewise.
	* elf-m68hc1x.c: Likewise.
	* elf32-mcore.c: Likewise.
	* elf32-mep.c: Likewise.
	* elf32-mt.c: Likewise.
	* elf32-ppc.c: Likewise.
	* elf32-xtensa.c: Likewise.
	* elf64-ppc.c: Likewise.
	* elfxx-mips.c: Likewise.
	* netbsd.h: Likewise.
	* nlmcode.h: Likewise.
	* vms-alpha.c: Likewise.
	* po/bfd.pot: Regenerate.
	* po/SRC-POTFILES.in: Regenerate.

binutils/ChangeLog
2011-06-02  Nick Clifton  <nickc@redhat.com>

	* resres.c: Fix spelling typo.
	* windint.h: Likewise.
	* windmc.c: Likewise.
	* windres.c: Likewise.
	* po/POTFILES.in: Regenerate.
	* po/binutils.pot: Regenerate.

gas/ChangeLog
2011-06-02  Nick Clifton  <nickc@redhat.com>

	* as.c: Fix spelling typo.
	* read.c: Likewise.
	* config/tc-ppc.c: Likewise.
	* po/gas.pit: Regenerate.

gold/ChangeLog
2011-06-02  Nick Clifton  <nickc@redhat.com>

	* dynobj.h: Fix spelling mistake in comment.
	* output.cc: Likewise.

include/coff/ChangeLog
2011-06-02  Nick Clifton  <nickc@redhat.com>

* i860.h: Fix spelling mistake in comment.

include/elf/ChangeLog
2011-06-02  Nick Clifton  <nickc@redhat.com>

	* common.h: Fix spelling mistake in comment.
	* reloc-macros.h: Likewise.

ld/ChangeLog
2011-06-02  Nick Clifton  <nickc@redhat.com>

	* lexsup.c: Fix spelling mistake in comment.
	* scripttempl/epocpe.sc: Likewise.
	* scripttempl/i386beos.sc: Likewise.
	* scripttempl/mcorepe.sc: Likewise.
	* scripttempl/pe.sc: Likewise.
	* scripttempl/pep.sc: Likewise.
	* po/ld.pot: Regenerate.

opcodes/ChangeLog
2011-06-02  Nick Clifton  <nickc@redhat.com>

	* arm-dis.c: Fix spelling mistakes.
	* op/opcodes.pot: Regenerate.
Index: bfd/coff-mcore.c
===================================================================
RCS file: /cvs/src/src/bfd/coff-mcore.c,v
retrieving revision 1.40
diff -u -3 -p -r1.40 coff-mcore.c
--- bfd/coff-mcore.c	27 Jun 2010 04:07:51 -0000	1.40
+++ bfd/coff-mcore.c	2 Jun 2011 12:55:30 -0000
@@ -377,7 +377,7 @@ coff_mcore_relocate_section (output_bfd,
   if (info->relocatable)
     return TRUE;
 
-  /* Check if we have the same endianess */
+  /* Check if we have the same endianness */
   if (   input_bfd->xvec->byteorder != output_bfd->xvec->byteorder
       && output_bfd->xvec->byteorder != BFD_ENDIAN_UNKNOWN)
     {
Index: bfd/coff-stgo32.c
===================================================================
RCS file: /cvs/src/src/bfd/coff-stgo32.c,v
retrieving revision 1.22
diff -u -3 -p -r1.22 coff-stgo32.c
--- bfd/coff-stgo32.c	5 Sep 2009 07:56:21 -0000	1.22
+++ bfd/coff-stgo32.c	2 Jun 2011 12:55:30 -0000
@@ -102,9 +102,9 @@ static bfd_boolean
 
 #include "coff-i386.c"
 
-/* This macro is used, because I cannot assume the endianess of the
+/* This macro is used, because I cannot assume the endianness of the
    host system.  */
 #define _H(index) (H_GET_16 (abfd, (header+index*2)))
 
 /* These bytes are a 2048-byte DOS executable, which loads the COFF
    image into memory and then runs it. It is called 'stub'.  */
Index: bfd/elf32-arm.c
===================================================================
RCS file: /cvs/src/src/bfd/elf32-arm.c,v
retrieving revision 1.267
diff -u -3 -p -r1.267 elf32-arm.c
--- bfd/elf32-arm.c	31 May 2011 14:07:57 -0000	1.267
+++ bfd/elf32-arm.c	2 Jun 2011 12:55:32 -0000
@@ -10233,7 +10233,7 @@ elf32_arm_relocate_section (bfd *       
 		    - relocation;
 		  addend += msec->output_section->vma + msec->output_offset;
 
-		  /* Cases here must match those in the preceeding
+		  /* Cases here must match those in the preceding
 		     switch statement.  */
 		  switch (r_type)
 		    {
@@ -15448,7 +15448,7 @@ elf32_arm_merge_private_bfd_data (bfd * 
   bfd_boolean flags_compatible = TRUE;
   asection *sec;
 
-  /* Check if we have the same endianess.  */
+  /* Check if we have the same endianness.  */
   if (! _bfd_generic_verify_endian_match (ibfd, obfd))
     return FALSE;
 
Index: bfd/elf32-m68hc1x.c
===================================================================
RCS file: /cvs/src/src/bfd/elf32-m68hc1x.c,v
retrieving revision 1.39
diff -u -3 -p -r1.39 elf32-m68hc1x.c
--- bfd/elf32-m68hc1x.c	25 Oct 2010 15:54:14 -0000	1.39
+++ bfd/elf32-m68hc1x.c	2 Jun 2011 12:55:33 -0000
@@ -1188,7 +1188,7 @@ _bfd_m68hc11_elf_merge_private_bfd_data 
   flagword new_flags;
   bfd_boolean ok = TRUE;
 
-  /* Check if we have the same endianess */
+  /* Check if we have the same endianness */
   if (!_bfd_generic_verify_endian_match (ibfd, obfd))
     return FALSE;
 
Index: bfd/elf32-mcore.c
===================================================================
RCS file: /cvs/src/src/bfd/elf32-mcore.c,v
retrieving revision 1.53
diff -u -3 -p -r1.53 elf32-mcore.c
--- bfd/elf32-mcore.c	25 Oct 2010 15:54:14 -0000	1.53
+++ bfd/elf32-mcore.c	2 Jun 2011 12:55:33 -0000
@@ -55,7 +55,7 @@ mcore_elf_merge_private_bfd_data (bfd * 
   flagword old_flags;
   flagword new_flags;
 
-  /* Check if we have the same endianess.  */
+  /* Check if we have the same endianness.  */
   if (! _bfd_generic_verify_endian_match (ibfd, obfd))
     return FALSE;
 
Index: bfd/elf32-mep.c
===================================================================
RCS file: /cvs/src/src/bfd/elf32-mep.c,v
retrieving revision 1.15
diff -u -3 -p -r1.15 elf32-mep.c
--- bfd/elf32-mep.c	14 Jan 2011 12:35:56 -0000	1.15
+++ bfd/elf32-mep.c	2 Jun 2011 12:55:33 -0000
@@ -606,7 +606,7 @@ mep_elf_merge_private_bfd_data (bfd * ib
   flagword old_flags, new_flags;
   flagword old_partial, new_partial;
 
-  /* Check if we have the same endianess.  */
+  /* Check if we have the same endianness.  */
   if (_bfd_generic_verify_endian_match (ibfd, obfd) == FALSE)
     return FALSE;
 
Index: bfd/elf32-mt.c
===================================================================
RCS file: /cvs/src/src/bfd/elf32-mt.c,v
retrieving revision 1.13
diff -u -3 -p -r1.13 elf32-mt.c
--- bfd/elf32-mt.c	25 Oct 2010 15:54:14 -0000	1.13
+++ bfd/elf32-mt.c	2 Jun 2011 12:55:33 -0000
@@ -521,7 +521,7 @@ mt_elf_merge_private_bfd_data (bfd * ibf
   flagword     old_flags, new_flags;
   bfd_boolean  ok = TRUE;
 
-  /* Check if we have the same endianess.  */
+  /* Check if we have the same endianness.  */
   if (_bfd_generic_verify_endian_match (ibfd, obfd) == FALSE)
     return FALSE;
 
Index: bfd/elf32-ppc.c
===================================================================
RCS file: /cvs/src/src/bfd/elf32-ppc.c,v
retrieving revision 1.296
diff -u -3 -p -r1.296 elf32-ppc.c
--- bfd/elf32-ppc.c	23 May 2011 06:22:50 -0000	1.296
+++ bfd/elf32-ppc.c	2 Jun 2011 12:55:34 -0000
@@ -4145,7 +4145,7 @@ ppc_elf_merge_private_bfd_data (bfd *ibf
   if (!is_ppc_elf (ibfd) || !is_ppc_elf (obfd))
     return TRUE;
 
-  /* Check if we have the same endianess.  */
+  /* Check if we have the same endianness.  */
   if (! _bfd_generic_verify_endian_match (ibfd, obfd))
     return FALSE;
 
Index: bfd/elf32-xtensa.c
===================================================================
RCS file: /cvs/src/src/bfd/elf32-xtensa.c,v
retrieving revision 1.128
diff -u -3 -p -r1.128 elf32-xtensa.c
--- bfd/elf32-xtensa.c	25 Oct 2010 15:54:14 -0000	1.128
+++ bfd/elf32-xtensa.c	2 Jun 2011 12:55:36 -0000
@@ -3466,7 +3466,7 @@ elf_xtensa_merge_private_bfd_data (bfd *
   unsigned out_mach, in_mach;
   flagword out_flag, in_flag;
 
-  /* Check if we have the same endianess.  */
+  /* Check if we have the same endianness.  */
   if (!_bfd_generic_verify_endian_match (ibfd, obfd))
     return FALSE;
 
Index: bfd/elf64-ppc.c
===================================================================
RCS file: /cvs/src/src/bfd/elf64-ppc.c,v
retrieving revision 1.352
diff -u -3 -p -r1.352 elf64-ppc.c
--- bfd/elf64-ppc.c	23 May 2011 06:22:51 -0000	1.352
+++ bfd/elf64-ppc.c	2 Jun 2011 12:55:38 -0000
@@ -2733,7 +2733,7 @@ ppc64_elf_write_core_note (bfd *abfd, ch
 static bfd_boolean
 ppc64_elf_merge_private_bfd_data (bfd *ibfd, bfd *obfd)
 {
-  /* Check if we have the same endianess.  */
+  /* Check if we have the same endianness.  */
   if (ibfd->xvec->byteorder != obfd->xvec->byteorder
       && ibfd->xvec->byteorder != BFD_ENDIAN_UNKNOWN
       && obfd->xvec->byteorder != BFD_ENDIAN_UNKNOWN)
Index: bfd/elfxx-mips.c
===================================================================
RCS file: /cvs/src/src/bfd/elfxx-mips.c,v
retrieving revision 1.284
diff -u -3 -p -r1.284 elfxx-mips.c
--- bfd/elfxx-mips.c	15 May 2011 18:52:00 -0000	1.284
+++ bfd/elfxx-mips.c	2 Jun 2011 12:55:39 -0000
@@ -12525,7 +12526,7 @@ _bfd_mips_elf_merge_private_bfd_data (bf
   bfd_boolean null_input_bfd = TRUE;
   asection *sec;
 
-  /* Check if we have the same endianess */
+  /* Check if we have the same endianness.  */
   if (! _bfd_generic_verify_endian_match (ibfd, obfd))
     {
       (*_bfd_error_handler)
Index: bfd/netbsd.h
===================================================================
RCS file: /cvs/src/src/bfd/netbsd.h,v
retrieving revision 1.10
diff -u -3 -p -r1.10 netbsd.h
--- bfd/netbsd.h	3 Jul 2007 14:26:42 -0000	1.10
+++ bfd/netbsd.h	2 Jun 2011 12:55:39 -0000
@@ -105,10 +105,10 @@ MY (write_object_contents) (bfd *abfd)
       break;
     }
 
-  /* The NetBSD magic number is always big-endian */
+  /* The NetBSD magic number is always big-endian.  */
 #ifndef TARGET_IS_BIG_ENDIAN_P
   /* XXX aren't there any macro to change byteorder of a word independent of
-     the host's or target's endianesses?  */
+     the host's or target's endiannesses?  */
   execp->a_info
     = (execp->a_info & 0xff) << 24 | (execp->a_info & 0xff00) << 8
       | (execp->a_info & 0xff0000) >> 8 | (execp->a_info & 0xff000000) >> 24;
Index: bfd/nlmcode.h
===================================================================
RCS file: /cvs/src/src/bfd/nlmcode.h,v
retrieving revision 1.22
diff -u -3 -p -r1.22 nlmcode.h
--- bfd/nlmcode.h	3 Jul 2007 14:26:42 -0000	1.22
+++ bfd/nlmcode.h	2 Jun 2011 12:55:39 -0000
@@ -491,7 +491,7 @@ nlm_object_p (bfd *abfd)
 		  NLM_SIGNATURE_SIZE) != 0)
     goto got_wrong_format_error;
 
-  /* There's no supported way to discover the endianess of an NLM, so test for
+  /* There's no supported way to discover the endianness of an NLM, so test for
      a sane version number after doing byte swapping appropriate for this
      XVEC.  (Hack alert!)  */
   if (i_fxdhdrp->version > 0xFFFF)
Index: bfd/vms-alpha.c
===================================================================
RCS file: /cvs/src/src/bfd/vms-alpha.c,v
retrieving revision 1.44
diff -u -3 -p -r1.44 vms-alpha.c
--- bfd/vms-alpha.c	6 May 2011 10:41:11 -0000	1.44
+++ bfd/vms-alpha.c	2 Jun 2011 12:55:40 -0000
@@ -440,7 +440,7 @@ struct alpha_vms_link_hash_table
 {
   struct bfd_link_hash_table root;
 
-  /* Vector of shared libaries.  */
+  /* Vector of shared libraries.  */
   struct vector_type shrlibs;
 
   /* Fixup section.  */
Index: binutils/resres.c
===================================================================
RCS file: /cvs/src/src/binutils/resres.c,v
retrieving revision 1.15
diff -u -3 -p -r1.15 resres.c
--- binutils/resres.c	11 Dec 2009 13:42:06 -0000	1.15
+++ binutils/resres.c	2 Jun 2011 12:55:40 -0000
@@ -98,7 +98,7 @@ read_res_file (const char *fn)
   off = 0;
 
   if (! probe_binary (&wrbfd, flen))
-    set_windres_bfd_endianess (&wrbfd, ! target_is_bigendian);
+    set_windres_bfd_endianness (&wrbfd, ! target_is_bigendian);
 
   skip_null_resource (&wrbfd, &off, flen);
 
Index: binutils/windint.h
===================================================================
RCS file: /cvs/src/src/binutils/windint.h,v
retrieving revision 1.2
diff -u -3 -p -r1.2 windint.h
--- binutils/windint.h	5 Jul 2007 16:54:45 -0000	1.2
+++ binutils/windint.h	2 Jun 2011 12:55:40 -0000
@@ -1083,6 +1083,6 @@ extern rc_uint_type windres_get_16 (wind
 extern rc_uint_type windres_get_32 (windres_bfd *, const void *, rc_uint_type);
 
 extern void set_windres_bfd (windres_bfd *, bfd *, asection *, rc_uint_type);
-extern void set_windres_bfd_endianess (windres_bfd *, int);
+extern void set_windres_bfd_endianness (windres_bfd *, int);
 
 #endif
Index: binutils/windmc.c
===================================================================
RCS file: /cvs/src/src/binutils/windmc.c,v
retrieving revision 1.10
diff -u -3 -p -r1.10 windmc.c
--- binutils/windmc.c	15 Nov 2010 23:54:23 -0000	1.10
+++ binutils/windmc.c	2 Jun 2011 12:55:40 -0000
@@ -205,7 +205,7 @@ usage (FILE *stream, int status)
   -C --codepage_in=<val>       Set codepage when reading mc text file\n\
   -d --decimal_values          Print values to text files decimal\n\
   -e --extension=<extension>   Set header extension used on export header file\n\
-  -F --target <target>         Specify output target for endianess.\n\
+  -F --target <target>         Specify output target for endianness.\n\
   -h --headerdir=<directory>   Set the export directory for headers\n\
   -u --unicode_in              Read input file as UTF16 file\n\
   -U --unicode_out             Write binary messages as UFT16\n\
@@ -231,7 +231,7 @@ usage (FILE *stream, int status)
 }
 
 static void
-set_endianess (bfd *abfd, const char *target)
+set_endianness (bfd *abfd, const char *target)
 {
   const bfd_target *target_vec;
 
@@ -239,7 +239,7 @@ set_endianess (bfd *abfd, const char *ta
   target_vec = bfd_get_target_info (target, abfd, &target_is_bigendian, NULL,
 				   &def_target_arch);
   if (! target_vec)
-    fatal ("Can't detect target endianess and architecture.");
+    fatal ("Can't detect target endianness and architecture.");
   if (! def_target_arch)
     fatal ("Can't detect architecture.");
 }
@@ -1054,7 +1054,7 @@ main (int argc, char **argv)
       ++optind;
     }
 
-  set_endianess (NULL, target);
+  set_endianness (NULL, target);
 
   if (input_filename == NULL)
     {
Index: binutils/windres.c
===================================================================
RCS file: /cvs/src/src/binutils/windres.c,v
retrieving revision 1.43
diff -u -3 -p -r1.43 windres.c
--- binutils/windres.c	13 Apr 2011 07:50:14 -0000	1.43
+++ binutils/windres.c	2 Jun 2011 12:55:40 -0000
@@ -54,7 +54,7 @@ int verbose = 0;
 int target_is_bigendian = 0;
 const char *def_target_arch;
 
-static void set_endianess (bfd *, const char *);
+static void set_endianness (bfd *, const char *);
 
 /* An enumeration of format types.  */
 
@@ -1049,7 +1049,7 @@ main (int argc, char **argv)
 	output_format = format_from_filename (output_filename, 0);
     }
 
-  set_endianess (NULL, target);
+  set_endianness (NULL, target);
 
   /* Read the input file.  */
   switch (input_format)
@@ -1098,7 +1098,7 @@ main (int argc, char **argv)
 }
 
 static void
-set_endianess (bfd *abfd, const char *target)
+set_endianness (bfd *abfd, const char *target)
 {
   const bfd_target *target_vec;
 
@@ -1106,7 +1106,7 @@ set_endianess (bfd *abfd, const char *ta
   target_vec = bfd_get_target_info (target, abfd, &target_is_bigendian, NULL,
                                    &def_target_arch);
   if (! target_vec)
-    fatal ("Can't detect target endianess and architecture.");
+    fatal ("Can't detect target endianness and architecture.");
   if (! def_target_arch)
     fatal ("Can't detect architecture.");
 }
@@ -1127,7 +1127,7 @@ windres_open_as_binary (const char *file
 }
 
 void
-set_windres_bfd_endianess (windres_bfd *wrbfd, int is_bigendian)
+set_windres_bfd_endianness (windres_bfd *wrbfd, int is_bigendian)
 {
   assert (!! wrbfd);
   switch (WR_KIND(wrbfd))
Index: gas/as.c
===================================================================
RCS file: /cvs/src/src/gas/as.c,v
retrieving revision 1.96
diff -u -3 -p -r1.96 as.c
--- gas/as.c	16 Mar 2011 12:58:25 -0000	1.96
+++ gas/as.c	2 Jun 2011 12:55:41 -0000
@@ -461,7 +461,7 @@ parse_args (int * pargc, char *** pargv)
   static const struct option std_longopts[] =
   {
     /* Note: commas are placed at the start of the line rather than
-       the end of the preceeding line so that it is simpler to
+       the end of the preceding line so that it is simpler to
        selectively add and remove lines from this list.  */
     {"alternate", no_argument, NULL, OPTION_ALTERNATE}
     /* The entry for "a" is here to prevent getopt_long_only() from
Index: gas/read.c
===================================================================
RCS file: /cvs/src/src/gas/read.c,v
retrieving revision 1.172
diff -u -3 -p -r1.172 read.c
--- gas/read.c	6 May 2011 14:48:56 -0000	1.172
+++ gas/read.c	2 Jun 2011 12:55:41 -0000
@@ -2935,7 +2935,7 @@ s_purgem (int ignore ATTRIBUTE_UNUSED)
 static void
 s_bad_end (int endr)
 {
-  as_warn (_(".end%c encountered without preceeding %s"),
+  as_warn (_(".end%c encountered without preceding %s"),
 	   endr ? 'r' : 'm',
 	   endr ? ".rept, .irp, or .irpc" : ".macro");
   demand_empty_rest_of_line ();
Index: gas/config/tc-ppc.c
===================================================================
RCS file: /cvs/src/src/gas/config/tc-ppc.c,v
retrieving revision 1.178
diff -u -3 -p -r1.178 tc-ppc.c
--- gas/config/tc-ppc.c	18 May 2011 07:58:35 -0000	1.178
+++ gas/config/tc-ppc.c	2 Jun 2011 12:55:42 -0000
@@ -1153,7 +1154,7 @@ md_parse_option (int c, char *arg)
       else if (strcmp (arg, "emb") == 0)
 	ppc_flags |= EF_PPC_EMB;
 
-      /* -mlittle/-mbig set the endianess.  */
+      /* -mlittle/-mbig set the endianness.  */
       else if (strcmp (arg, "little") == 0
 	       || strcmp (arg, "little-endian") == 0)
 	{
Index: gold/dynobj.h
===================================================================
RCS file: /cvs/src/src/gold/dynobj.h,v
retrieving revision 1.44
diff -u -3 -p -r1.44 dynobj.h
--- gold/dynobj.h	24 May 2011 21:57:27 -0000	1.44
+++ gold/dynobj.h	2 Jun 2011 12:55:43 -0000
@@ -652,7 +652,7 @@ class Versions
   // Contents of --version-script, if passed, or NULL.
   const Version_script_info& version_script_;
   // Whether we need to insert a base version.  This is only used for
-  // shared libaries and is cleared when the base version is defined.
+  // shared libraries and is cleared when the base version is defined.
   bool needs_base_version_;
 };
 
Index: gold/output.cc
===================================================================
RCS file: /cvs/src/src/gold/output.cc,v
retrieving revision 1.147
diff -u -3 -p -r1.147 output.cc
--- gold/output.cc	25 May 2011 00:17:47 -0000	1.147
+++ gold/output.cc	2 Jun 2011 12:55:43 -0000
@@ -479,7 +479,7 @@ Output_file_header::do_write(Output_file
     }
 }
 
-// Write out the file header with appropriate size and endianess.
+// Write out the file header with appropriate size and endianness.
 
 template<int size, bool big_endian>
 void
Index: include/coff/i860.h
===================================================================
RCS file: /cvs/src/src/include/coff/i860.h,v
retrieving revision 1.6
diff -u -3 -p -r1.6 i860.h
--- include/coff/i860.h	15 Apr 2010 10:26:07 -0000	1.6
+++ include/coff/i860.h	2 Jun 2011 12:55:43 -0000
@@ -58,7 +58,7 @@ struct external_reloc
 #define RELSZ 10
 
 /* The relocation directory entry types.
-     PAIR   : The low half that follows relates to the preceeding HIGH[ADJ].
+     PAIR   : The low half that follows relates to the preceding HIGH[ADJ].
      HIGH   : The high half of a 32-bit constant.
      LOWn   : The low half, insn bits 15..(n-1), 2^n-byte aligned. 
      SPLITn : The low half, insn bits 20..16 and 10..(n-1), 2^n-byte aligned. 
Index: include/elf/common.h
===================================================================
RCS file: /cvs/src/src/include/elf/common.h,v
retrieving revision 1.127
diff -u -3 -p -r1.127 common.h
--- include/elf/common.h	15 Apr 2011 11:14:01 -0000	1.127
+++ include/elf/common.h	2 Jun 2011 12:55:44 -0000
@@ -159,7 +159,7 @@
 #define EM_MMA		 54	/* Fujitsu Multimedia Accelerator */
 #define EM_PCP		 55	/* Siemens PCP */
 #define EM_NCPU		 56	/* Sony nCPU embedded RISC processor */
-#define EM_NDR1		 57	/* Denso NDR1 microprocesspr */
+#define EM_NDR1		 57	/* Denso NDR1 microprocessor */
 #define EM_STARCORE	 58	/* Motorola Star*Core processor */
 #define EM_ME16		 59	/* Toyota ME16 processor */
 #define EM_ST100	 60	/* STMicroelectronics ST100 processor */
Index: include/elf/reloc-macros.h
===================================================================
RCS file: /cvs/src/src/include/elf/reloc-macros.h,v
retrieving revision 1.11
diff -u -3 -p -r1.11 reloc-macros.h
--- include/elf/reloc-macros.h	15 Apr 2010 10:26:08 -0000	1.11
+++ include/elf/reloc-macros.h	2 Jun 2011 12:55:44 -0000
@@ -45,10 +45,10 @@
 
    Note: The value of the symbol defined in the END_RELOC_NUMBERS
    macro (R_foo_count in the case of the example above) will be
-   set to the value of the whichever *_RELOC macro preceeds it plus
+   set to the value of the whichever *_RELOC macro precedes it plus
    one.  Therefore if you intend to use the symbol as a sentinel for
    the highest valid macro value you should make sure that the
-   preceeding *_RELOC macro is the highest valid number.  ie a
+   preceding *_RELOC macro is the highest valid number.  ie a
    declaration like this:
 
    	START_RELOC_NUMBERS (foo)
Index: ld/lexsup.c
===================================================================
RCS file: /cvs/src/src/ld/lexsup.c,v
retrieving revision 1.125
diff -u -3 -p -r1.125 lexsup.c
--- ld/lexsup.c	23 Mar 2011 19:53:06 -0000	1.125
+++ ld/lexsup.c	2 Jun 2011 12:55:45 -0000
@@ -454,7 +454,7 @@ static const struct ld_option ld_options
     '\0', NULL, N_("Do not allow unresolved references in object files"),
     TWO_DASHES },
   { {"allow-shlib-undefined", no_argument, NULL, OPTION_ALLOW_SHLIB_UNDEFINED},
-    '\0', NULL, N_("Allow unresolved references in shared libaries"),
+    '\0', NULL, N_("Allow unresolved references in shared libraries"),
     TWO_DASHES },
   { {"no-allow-shlib-undefined", no_argument, NULL,
      OPTION_NO_ALLOW_SHLIB_UNDEFINED},
Index: ld/scripttempl/epocpe.sc
===================================================================
RCS file: /cvs/src/src/ld/scripttempl/epocpe.sc,v
retrieving revision 1.3
diff -u -3 -p -r1.3 epocpe.sc
--- ld/scripttempl/epocpe.sc	9 Sep 2009 11:59:14 -0000	1.3
+++ ld/scripttempl/epocpe.sc	2 Jun 2011 12:55:45 -0000
@@ -74,7 +74,7 @@ SECTIONS
      on fork.  This used to be named ".data$nocopy".  The linker used
      to include this between __data_start__ and __data_end__, but that
      breaks building the cygwin32 dll.  Instead, we name the section
-     ".data_cygwin_nocopy" and explictly include it after __data_end__. */
+     ".data_cygwin_nocopy" and explicitly include it after __data_end__. */
 
   .data ${RELOCATING+BLOCK(__section_alignment__)} : 
   {
Index: ld/scripttempl/i386beos.sc
===================================================================
RCS file: /cvs/src/src/ld/scripttempl/i386beos.sc,v
retrieving revision 1.3
diff -u -3 -p -r1.3 i386beos.sc
--- ld/scripttempl/i386beos.sc	9 Sep 2009 11:59:14 -0000	1.3
+++ ld/scripttempl/i386beos.sc	2 Jun 2011 12:55:45 -0000
@@ -68,7 +68,7 @@ SECTIONS
      on fork.  This used to be named ".data$nocopy".  The linker used
      to include this between __data_start__ and __data_end__, but that
      breaks building the cygwin32 dll.  Instead, we name the section
-     ".data_cygwin_nocopy" and explictly include it after __data_end__. */
+     ".data_cygwin_nocopy" and explicitly include it after __data_end__. */
 
   .data ${RELOCATING+BLOCK(__section_alignment__)} : 
   {
Index: ld/scripttempl/mcorepe.sc
===================================================================
RCS file: /cvs/src/src/ld/scripttempl/mcorepe.sc,v
retrieving revision 1.6
diff -u -3 -p -r1.6 mcorepe.sc
--- ld/scripttempl/mcorepe.sc	9 Sep 2009 11:59:14 -0000	1.6
+++ ld/scripttempl/mcorepe.sc	2 Jun 2011 12:55:45 -0000
@@ -74,7 +74,7 @@ SECTIONS
      on fork.  This used to be named ".data$nocopy".  The linker used
      to include this between __data_start__ and __data_end__, but that
      breaks building the cygwin32 dll.  Instead, we name the section
-     ".data_cygwin_nocopy" and explictly include it after __data_end__. */
+     ".data_cygwin_nocopy" and explicitly include it after __data_end__. */
 
   .data ${RELOCATING+BLOCK(__section_alignment__)} : 
   {
Index: ld/scripttempl/pe.sc
===================================================================
RCS file: /cvs/src/src/ld/scripttempl/pe.sc,v
retrieving revision 1.26
diff -u -3 -p -r1.26 pe.sc
--- ld/scripttempl/pe.sc	7 May 2011 14:29:08 -0000	1.26
+++ ld/scripttempl/pe.sc	2 Jun 2011 12:55:45 -0000
@@ -90,7 +90,7 @@ SECTIONS
      on fork.  This used to be named ".data$nocopy".  The linker used
      to include this between __data_start__ and __data_end__, but that
      breaks building the cygwin32 dll.  Instead, we name the section
-     ".data_cygwin_nocopy" and explictly include it after __data_end__. */
+     ".data_cygwin_nocopy" and explicitly include it after __data_end__. */
 
   .data ${RELOCATING+BLOCK(__section_alignment__)} : 
   {
Index: ld/scripttempl/pep.sc
===================================================================
RCS file: /cvs/src/src/ld/scripttempl/pep.sc,v
retrieving revision 1.15
diff -u -3 -p -r1.15 pep.sc
--- ld/scripttempl/pep.sc	7 May 2011 14:29:09 -0000	1.15
+++ ld/scripttempl/pep.sc	2 Jun 2011 12:55:45 -0000
@@ -91,7 +91,7 @@ SECTIONS
      on fork.  This used to be named ".data$nocopy".  The linker used
      to include this between __data_start__ and __data_end__, but that
      breaks building the cygwin32 dll.  Instead, we name the section
-     ".data_cygwin_nocopy" and explictly include it after __data_end__. */
+     ".data_cygwin_nocopy" and explicitly include it after __data_end__. */
 
   .data ${RELOCATING+BLOCK(__section_alignment__)} : 
   {
Index: opcodes/arm-dis.c
===================================================================
RCS file: /cvs/src/src/opcodes/arm-dis.c,v
retrieving revision 1.143
diff -u -3 -p -r1.143 arm-dis.c
--- opcodes/arm-dis.c	19 Apr 2011 07:44:12 -0000	1.143
+++ opcodes/arm-dis.c	2 Jun 2011 12:55:46 -0000
@@ -4702,7 +4702,7 @@ print_insn (bfd_vma pc, struct disassemb
 	  if (!found)
 	    {
 	      /* No mapping symbol found at this address.  Look backwards
-		 for a preceeding one.  */
+		 for a preceding one.  */
 	      for (n = start - 1; n >= 0; n--)
 		{
 		  if (get_map_sym_type (info, n, &type))
@@ -4762,7 +4762,7 @@ print_insn (bfd_vma pc, struct disassemb
 	  if (!found)
 	    {
 	      /* No mapping symbol found at this address.  Look backwards
-		 for a preceeding one.  */
+		 for a preceding one.  */
 	      for (n = start - 1; n >= 0; n--)
 		{
 		  if (get_sym_code_type (info, n, &type))
@@ -4984,5 +4984,5 @@ the -M switch:\n"));
 	     regnames[i].description);
 
   fprintf (stream, "  force-thumb              Assume all insns are Thumb insns\n");
-  fprintf (stream, "  no-force-thumb           Examine preceeding label to determine an insn's type\n\n");
+  fprintf (stream, "  no-force-thumb           Examine preceding label to determine an insn's type\n\n");
 }

Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Index: bfd/elf32-avr.c
===================================================================
RCS file: /cvs/src/src/bfd/elf32-avr.c,v
retrieving revision 1.50
diff -u -3 -p -r1.50 elf32-avr.c
--- bfd/elf32-avr.c	22 Mar 2011 18:10:42 -0000	1.50
+++ bfd/elf32-avr.c	2 Jun 2011 12:55:32 -0000
@@ -2008,10 +2008,10 @@ elf32_avr_relax_section (bfd *abfd,
                 if ((0x95 == next_insn_msb) && (0x08 == next_insn_lsb))
                   {
                     /* The next insn is a ret. We possibly could delete
-                       this ret. First we need to check for preceeding
+                       this ret. First we need to check for preceding
                        sbis/sbic/sbrs or cpse "skip" instructions.  */
 
-                    int there_is_preceeding_non_skip_insn = 1;
+                    int there_is_preceding_non_skip_insn = 1;
                     bfd_vma address_of_ret;
 
                     address_of_ret = dot + insn_size;
@@ -2023,51 +2023,52 @@ elf32_avr_relax_section (bfd *abfd,
                       printf ("found jmp / ret sequence at address 0x%x\n",
                               (int) dot);
 
                     /* We have to make sure that there is a preceeding insn.  */
                     if (irel->r_offset >= 2)
                       {
-                        unsigned char preceeding_msb;
-                        unsigned char preceeding_lsb;
-                        preceeding_msb =
+                        unsigned char preceding_msb;
+                        unsigned char preceding_lsb;
+
+                        preceding_msb =
 			  bfd_get_8 (abfd, contents + irel->r_offset - 1);
-                        preceeding_lsb =
+                        preceding_lsb =
 			  bfd_get_8 (abfd, contents + irel->r_offset - 2);
 
                         /* sbic.  */
-                        if (0x99 == preceeding_msb)
-                          there_is_preceeding_non_skip_insn = 0;
+                        if (0x99 == preceding_msb)
+                          there_is_preceding_non_skip_insn = 0;
 
                         /* sbis.  */
-                        if (0x9b == preceeding_msb)
-                          there_is_preceeding_non_skip_insn = 0;
+                        if (0x9b == preceding_msb)
+                          there_is_preceding_non_skip_insn = 0;
 
                         /* sbrc */
-                        if ((0xfc == (preceeding_msb & 0xfe)
-			     && (0x00 == (preceeding_lsb & 0x08))))
-                          there_is_preceeding_non_skip_insn = 0;
+                        if ((0xfc == (preceding_msb & 0xfe)
+			     && (0x00 == (preceding_lsb & 0x08))))
+                          there_is_preceding_non_skip_insn = 0;
 
                         /* sbrs */
-                        if ((0xfe == (preceeding_msb & 0xfe)
-			     && (0x00 == (preceeding_lsb & 0x08))))
-                          there_is_preceeding_non_skip_insn = 0;
+                        if ((0xfe == (preceding_msb & 0xfe)
+			     && (0x00 == (preceding_lsb & 0x08))))
+                          there_is_preceding_non_skip_insn = 0;
 
                         /* cpse */
-                        if (0x10 == (preceeding_msb & 0xfc))
-                          there_is_preceeding_non_skip_insn = 0;
+                        if (0x10 == (preceding_msb & 0xfc))
+                          there_is_preceding_non_skip_insn = 0;
 
-                        if (there_is_preceeding_non_skip_insn == 0)
+                        if (there_is_preceding_non_skip_insn == 0)
                           if (debug_relax)
-                            printf ("preceeding skip insn prevents deletion of"
-                                    " ret insn at addr 0x%x in section %s\n",
+                            printf ("preceding skip insn prevents deletion of"
+                                    " ret insn at Addy 0x%x in section %s\n",
                                     (int) dot + 2, sec->name);
                       }
                     else
                       {
                         /* There is no previous instruction.  */
-                        there_is_preceeding_non_skip_insn = 0;
+                        there_is_preceding_non_skip_insn = 0;
                       }
 
-                    if (there_is_preceeding_non_skip_insn)
+                    if (there_is_preceding_non_skip_insn)
                       {
                         /* We now only have to make sure that there is no
                            local label defined at the address of the ret
@@ -2023,51 +2023,52 @@ elf32_avr_relax_section (bfd *abfd,
                               (int) dot);
 
-                    /* We have to make sure that there is a preceeding insn.  */
+                    /* We have to make sure that there is a preceding insn.  */
                     if (irel->r_offset >= 2)
                       {